@@ -12,8 +12,8 @@ SPIRIT_SWAP_FACTORY_ADDRESS = "0xEF45d134b73241eDa7703fa787148D9C9F4950b0"
 SPIRIT_SWAP_ROUTER_ADDRESS = "0x16327E3FbDaCA3bcF7E38F5Af2599D2DDc33aE52"
 
 # SUSHI_SWAP
-SUSHI_SWAPFACTORY_ADDRESS = "0xc35DADB65012eC5796536bD9864eD8773aBc74C4"
-SUSHI_SWAPROUTER_ADDRESS = "0x1b02dA8Cb0d097eB8D57A175b88c7D8b47997506"
+SUSHI_SWAP_FACTORY_ADDRESS = "0xc35DADB65012eC5796536bD9864eD8773aBc74C4"
+SUSHI_SWAP_ROUTER_ADDRESS = "0x1b02dA8Cb0d097eB8D57A175b88c7D8b47997506"
 
 # BEETHOVEN
 BEETHOVEN_VAULT_ADDRESS = "0x20dd72Ed959b6147912C2e529F0a0C651c33c9ce"
